@@ -1,3 +1,5 @@
+from __future__ import print_function
+
 from . import base_command
 import pprint
 
@@ -11,18 +13,17 @@ class Command(base_command.CustomBaseCommand):
 
     def handle(self, *args, **options):
         from django.conf import settings
-        args = map(str.upper, args)
+        args = list(map(str.upper, args))
         for k in dir(settings):
             if k.upper() == k:
                 v = getattr(settings, k)
-                found = not bool(args)
+                found = False
                 for arg in args:
                     if arg in k:
                         found = True
                         break
 
                 if found:
-                    print '%s: ' % k,
                     pprint.pprint(v)
 
         super(Command, self).handle(*args, **options)
